aboutsummaryrefslogtreecommitdiff
path: root/bh20simplewebuploader/main.py
diff options
context:
space:
mode:
authorAdam Novak2020-04-17 12:02:51 -0700
committerAdam Novak2020-04-17 12:02:51 -0700
commit3a10517123c261d5ce26f174b97764fcaad06e93 (patch)
tree69c16ec4ed43dfa8d207373b07a2157bf3dba1c0 /bh20simplewebuploader/main.py
parent6c09aa8e672acd8c0deb593150ab3d0e5893d2ae (diff)
downloadbh20-seq-resource-3a10517123c261d5ce26f174b97764fcaad06e93.tar.gz
bh20-seq-resource-3a10517123c261d5ce26f174b97764fcaad06e93.tar.lz
bh20-seq-resource-3a10517123c261d5ce26f174b97764fcaad06e93.zip
Create option dropdowns from an options file
Diffstat (limited to 'bh20simplewebuploader/main.py')
-rw-r--r--bh20simplewebuploader/main.py37
1 files changed, 31 insertions, 6 deletions
diff --git a/bh20simplewebuploader/main.py b/bh20simplewebuploader/main.py
index c7f63ea..c8fdc3f 100644
--- a/bh20simplewebuploader/main.py
+++ b/bh20simplewebuploader/main.py
@@ -60,14 +60,25 @@ def is_iri(string):
return string.startswith('http')
-def generate_form(schema):
+def generate_form(schema, options):
"""
- Linearize the schema and send a bunch of dicts.
+ Linearize the schema into a list of dicts.
+
Each dict either has a 'heading' (in which case we put a heading for a
form section in the template) or an 'id', 'label', 'type', and 'required'
- (in which case we make a form field in the template).
+ (in which case we make a form field in the template). Non-heading dicts
+ with type 'select' will have an 'options' field, with a list of (name,
+ value) tuples, and represent a form dropdown element.
+
+ Takes the deserialized metadata schema YAML, and also a deserialized YAML
+ of option values. The option values are keyed on (unscoped) field name in
+ the schema, and each is a dict of human readable option -> corresponding
+ IRI.
"""
+ print(schema)
+ print(options)
+
# Get the list of form components, one of which is the root
components = schema.get('$graph', [])
@@ -141,14 +152,27 @@ def generate_form(schema):
for item in walk_fields(field_type, parent_keys + [field_name], subtree_optional or optional):
yield item
else:
- # We know how to make a string input
+ # This is a leaf field. We need an input for it.
record = {}
record['id'] = '.'.join(parent_keys + [field_name])
record['label'] = name_to_label(field_name)
record['required'] = not optional and not subtree_optional
if ref_iri:
record['ref_iri'] = ref_iri
- if field_type == 'string':
+
+ print(field_name)
+
+ if field_name in options:
+ print("Has options: {}".format(options[field_name]))
+ # The field will be a 'select' type no matter what its real
+ # data type is.
+ record['type'] = 'select' # Not a real HTML input type. It's its own tag.
+ # We have a set of values to present
+ record['options'] = []
+ for name, value in options[field_name].items():
+ # Make a tuple for each one
+ record['options'].append((name, value))
+ elif field_type == 'string':
record['type'] = 'text' # HTML input type
elif field_type == 'int':
record['type'] = 'number'
@@ -161,7 +185,8 @@ def generate_form(schema):
# At startup, we need to load the metadata schema from the uploader module, so we can make a form for it
METADATA_SCHEMA = yaml.safe_load(pkg_resources.resource_stream("bh20sequploader", "bh20seq-schema.yml"))
-FORM_ITEMS = generate_form(METADATA_SCHEMA)
+METADATA_OPTION_DEFINITIONS = yaml.safe_load(pkg_resources.resource_stream("bh20sequploader", "bh20seq-options.yml"))
+FORM_ITEMS = generate_form(METADATA_SCHEMA, METADATA_OPTION_DEFINITIONS)
@app.route('/')
def send_form():